@@ -1,7 +1,10 @@
 from jenkinsapi.jenkins import Jenkins
 from .JenkinsSession import JenkinsSession
+from .Config import Config
 from ui.Login import Factory
 import re, sys
+import pickle
+
 
 class MrHat:
     '''
@@ -87,6 +90,54 @@ class MrHat:
                 return out
         return "MC_%s-001" % version
     
+    def get_repo_map(self):
+        try:
+            mapfile = open('jobmap.data', 'rb')
+            jobmap = pickle.load(mapfile)
+            mapfile.close()
+        except:
+            print "Creating Repo Map"
+            jobmap = self.create_repo_map()
+            
+        return jobmap
+        
+    def create_repo_map(self):
+        jobs = self.jenkins.keys()
+        try:
+            mapfile = open('jobmap.data', 'rb')
+            jobmap = pickle.load(mapfile)
+            mapfile.close()
+        except:
+            jobmap = {}
+
+        for job in jobs:
+            if job not in jobmap.keys():
+                config = Config(self.jenkins[job].get_config())
+                r = config.get_cvs_repo()
+                if r is not None:
+                    jobmap[job] = r
+                    mapfile = open('jobmap.data', 'wb')
+        
+                    pickle.dump(jobmap, mapfile)
+                    
+                    mapfile.close()     
+        return jobmap
+        
+    
+    def get_jobs_for_cvs_repo(self, repo):
+        out = []
+        jobmap = self.get_repo_map()
+        for job in jobmap.keys():
+            r = jobmap[job]
+            if repo == r:
+                out.append(job)
+        return out
+    
+    def move_to_git(self, job):
+        config = Config(self.jenkins[job].get_config())
+        gitconfig = config.create_git_config()
+        self.jenkins[job].update_config(gitconfig)
+    
     def __increment__(self, build_num):
         '''
         Increments the build number and returns a new zero filled build number
